@@ -512,4 +512,23 @@ CLOUDFORMATION_ACTIONS_ONLY_ACCEPTS_WILDCARD = [
     "sns:SetSMSAttributes",
     "sns:SetSubscriptionAttributes",
     "sns:Unsubscribe",
+    "xray:BatchGetTraces",
+    "xray:GetEncryptionConfig",
+    "xray:GetGroups",
+    "xray:GetInsight",
+    "xray:GetInsightEvents",
+    "xray:GetInsightImpactGraph",
+    "xray:GetInsightSummaries",
+    "xray:GetSamplingRules",
+    "xray:GetSamplingStatisticSummaries",
+    "xray:GetSamplingTargets",
+    "xray:GetServiceGraph",
+    "xray:GetTimeSeriesServiceStatistics",
+    "xray:GetTraceGraph",
+    "xray:GetTraceSummaries",
+    "xray:PutEncryptionConfig",
+    "xray:PutTelemetryRecords",
+    "xray:PutTraceSegments",
+    "xray:PutTraceSegments",
+    "xray:PutTraceSegments",
 ]
