@@ -1,5 +1,11 @@
+import importlib
+import logging
+import os
 import re
-from typing import List
+import sys
+from typing import Dict, List
+
+from pydantic import BaseModel
 
 from .rule_config import RuleConfig
 from .whitelist import AWS_ELASTICACHE_BACKUP_CANONICAL_IDS, AWS_ELB_LOGS_ACCOUNT_IDS
@@ -7,6 +13,8 @@ from .whitelist import rule_to_action_whitelist as default_rule_to_action_whitel
 from .whitelist import rule_to_resource_whitelist as default_rule_to_resource_whitelist
 from .whitelist import stack_whitelist as default_stack_whitelist
 
+logger = logging.getLogger(__file__)
+
 
 class Config:
     DEFAULT_ALLOWED_WORLD_OPEN_PORTS = [80, 443]
@@ -159,3 +167,28 @@ class Config:
                 whitelisted_rules += v
 
         return whitelisted_rules
+
+    def load_rules_config_file(self, filename: str):
+        if not os.path.exists(filename):
+            raise RuntimeError(f"{filename} doesn't exist")
+
+        try:
+            ext = os.path.splitext(filename)[1]
+            module_name = "__rules_config__"
+            if ext not in [".py", ".pyc"]:
+                raise RuntimeError("Configuration file should have a valid Python extension.")
+            spec = importlib.util.spec_from_file_location(module_name, filename)
+            module = importlib.util.module_from_spec(spec)
+            sys.modules[module_name] = module
+            spec.loader.exec_module(module)
+            rules_config = vars(module).get("RULES_CONFIG")
+            # Validate rules_config format
+            RulesConfigMapping(__root__=rules_config)
+            self.rules_config = rules_config
+        except Exception:
+            logger.exception(f"Failed to read config file: {filename}")
+            raise
+
+
+class RulesConfigMapping(BaseModel):
+    __root__: Dict[str, RuleConfig]
